@@ -117,6 +117,8 @@ class _ActionsContainer(SignatureArguments, argparse._ActionsContainer):
                 (action_class, completer_method),
                 {}
             )
+        if isinstance(action, ActionConfigFile) and getattr(self, '_print_config', None) is not None:
+            self.add_argument(self._print_config, action=_ActionPrintConfig)  # type: ignore
         for key in meta_keys:
             if key in action.dest:
                 raise ValueError('Argument with destination name "'+key+'" not allowed.')
@@ -221,8 +223,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser, LoggerProperty)
         self.parser_mode = parser_mode
         self.logger = logger
         self.error_handler = error_handler
-        if print_config is not None:
-            self.add_argument(print_config, action=_ActionPrintConfig)
+        self._print_config = print_config
         if version is not None:
             self.add_argument('--version', action='version', version='%(prog)s '+version, help='Print version and exit.')
         if parser_mode not in {'yaml', 'jsonnet'}:
@@ -708,6 +709,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser, LoggerProperty)
         format: str = 'parser_mode',
         skip_none: bool = True,
         skip_check: bool = False,
+        yaml_comments: bool = False,
     ) -> str:
         """Generates a yaml or json string for the given configuration object.
 
@@ -716,6 +718,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser, LoggerProperty)
             format: The output format: "yaml", "json", "json_indented" or "parser_mode".
             skip_none: Whether to exclude entries whose value is None.
             skip_check: Whether to skip parser checking.
+            yaml_comments: Whether to add help content as comments.
 
         Returns:
             The configuration in yaml or json format.
@@ -756,7 +759,11 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser, LoggerProperty)
         if format == 'parser_mode':
             format = 'yaml' if self.parser_mode == 'yaml' else 'json_indented'
         if format == 'yaml':
-            return yaml.safe_dump(cfg, **self.dump_yaml_kwargs)  # type: ignore
+            dump = yaml.safe_dump(cfg, **self.dump_yaml_kwargs)  # type: ignore
+            if yaml_comments:
+                formatter = self.formatter_class(self.prog)
+                dump = formatter.add_yaml_comments(dump)  # type: ignore
+            return dump
         elif format == 'json_indented':
             return json.dumps(cfg, indent=2, **self.dump_json_kwargs)+'\n'  # type: ignore
         elif format == 'json':
