@@ -117,9 +117,10 @@ class ActionTypeHint(Action):
         return inspect.isclass(typehint) and typehint not in leaf_types.union(root_types)
 
 
-    @staticmethod
-    def serialize(value, typehint):
-        return adapt_typehints(value, typehint, serialize=True)
+    def serialize(self, value):
+        if _is_action_value_list(self):
+            return [adapt_typehints(v, self._typehint, serialize=True) for v in value]
+        return adapt_typehints(value, self._typehint, serialize=True)
 
 
     def __call__(self, *args, **kwargs):
@@ -134,7 +135,10 @@ class ActionTypeHint(Action):
             if 'nargs' in kwargs and kwargs['nargs'] == 0:
                 raise ValueError('ActionTypeHint does not allow nargs=0.')
             return ActionTypeHint(**kwargs)
-        val = self._check_type(args[2])
+        if self.nargs == '?' and args[2] is None:
+            val = None
+        else:
+            val = self._check_type(args[2])
         setattr(args[1], self.dest, val)
 
 
@@ -151,7 +155,7 @@ class ActionTypeHint(Action):
                     config_path = None
                 path_meta = val.pop('__path__') if isinstance(val, dict) and '__path__' in val else None
                 try:
-                    val = adapt_typehints(val, self._typehint)
+                    val = adapt_typehints(val, self._typehint, skip=getattr(self, 'skip', None))
                 except ValueError as ex:
                     if isinstance(val, (int, float)) and config_path is None:
                         val = adapt_typehints(orig_val, self._typehint)
@@ -198,9 +202,9 @@ class ActionTypeHint(Action):
             return argcomplete_warn_redraw_prompt(prefix, msg)
 
 
-def adapt_typehints(val, typehint, serialize=False, instantiate_classes=False):
+def adapt_typehints(val, typehint, serialize=False, instantiate_classes=False, skip=None):
 
-    adapt_kwargs = {'serialize': serialize, 'instantiate_classes': instantiate_classes}
+    adapt_kwargs = {'serialize': serialize, 'instantiate_classes': instantiate_classes, 'skip': skip}
     subtypehints = getattr(typehint, '__args__', None)
     typehint_origin = getattr(typehint, '__origin__', typehint)
 
@@ -308,7 +312,7 @@ def adapt_typehints(val, typehint, serialize=False, instantiate_classes=False):
                 raise ValueError('"'+val['class_path']+'" is not a subclass of '+typehint.__name__)
             from .core import ArgumentParser
             parser = ArgumentParser(error_handler=None, parse_as_dict=True)
-            parser.add_class_arguments(val_class)
+            parser.add_class_arguments(val_class, skip=skip)
             if serialize and 'init_args' in val:
                 val['init_args'] = yaml.safe_load(parser.dump(val['init_args']))
             else:
