@@ -498,6 +498,7 @@ class SignaturesTests(unittest.TestCase):
                 pass
 
         parser = ArgumentParser()
+        parser.add_argument('--config', action=ActionConfigFile)
         parser.add_class_arguments(MyClass, 'g')
 
         out = StringIO()
@@ -546,8 +547,8 @@ class SignaturesTests(unittest.TestCase):
         help_str = StringIO()
         parser.print_help(help_str)
         self.assertIn('Linked arguments', help_str.getvalue())
-        self.assertIn('b.v1 <= a.v2', help_str.getvalue())
-        self.assertIn('b.v2 <= add(a.v1, a.v2)', help_str.getvalue())
+        self.assertIn('b.v1 <-- a.v2', help_str.getvalue())
+        self.assertIn('b.v2 <-- add(a.v1, a.v2)', help_str.getvalue())
         if docstring_parser_support:
             self.assertIn('b v1 help', help_str.getvalue())
 
